@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: parsec
-version: 3.1.9
-id: parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
-key: parse_7aUabKPjr5W6Al5Ge35AQl
+version: 3.1.11
+id: parsec-3.1.11-2df9dc070a05b018377712731c5dde62
+key: parse_AtBt9uDOS2NCyWnucTHV3y
 license: BSD3
 maintainer: Antoine Latter <aslatter@gmail.com>
 homepage: https://github.com/aslatter/parsec
@@ -34,10 +34,10 @@ exposed-modules:
     Text.ParserCombinators.Parsec.Prim
     Text.ParserCombinators.Parsec.Token
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/parsec-3.1.9
-library-dirs: /usr/lib/ghc-7.10.3/site-local/parsec-3.1.9
-data-dir: /usr/share/arm-linux-ghc-7.10.3/parsec-3.1.9
-hs-libraries: HSparsec-3.1.9-7aUabKPjr5W6Al5Ge35AQl
+import-dirs: /usr/lib/ghc-7.10.3/site-local/parsec-3.1.11
+library-dirs: /usr/lib/ghc-7.10.3/site-local/parsec-3.1.11
+data-dir: /usr/share/arm-linux-ghc-7.10.3/parsec-3.1.11
+hs-libraries: HSparsec-3.1.11-AtBt9uDOS2NCyWnucTHV3y
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
